@@ -13,6 +13,7 @@ import os
 import warnings
 warnings.filterwarnings("ignore", category=SyntaxWarning)
 
+__version__ = "1.0.62.12.1"
 
 global_options = optparse.OptionParser(
     usage="yoc COMMAND [ARGS]"
@@ -84,5 +85,9 @@ class YocCommand:
 
 
 def main():
+    if len(sys.argv) == 2:
+        if sys.argv[1] == '-V' or sys.argv[1] == '--version':
+            put_string(__version__)
+            return
     cmd = YocCommand()
     cmd.Execute(sys.argv[1:])
