@@ -31,12 +31,11 @@ class Component:
         self.version = ''
         self.depends = []
         self.description = ''
-        self.license = ''
         self.historyVersion = {}
         self.updated = ''
-        self.repo_url = ''
+        self.repo_url = os.path.join(self.conf.repo, '%s.git' % self.name)
         self.repo = None
-        self.yoc_version = ''
+        self.branch = self.conf.yoc_version
         self.source_files = []
         self.defconfig = {}
         self.build_config = None
@@ -46,7 +45,15 @@ class Component:
 
         self.depends_on = []  # 该组件被哪个组件依赖
         self.need_build = True
+        self.loaded = False
 
+    def check_file_integrity(self):
+        readme_file = os.path.join(self.path, 'README.md')
+        if not os.path.exists(readme_file):
+            put_string("There is no `README.md` file found in %s component,please add it first." % self.name)
+            return False
+        return True
+        
     def json_dumps(self):
         js = {
             'name': self.name,
@@ -58,12 +65,13 @@ class Component:
         }
         return json.dumps(js, ensure_ascii=False)
 
+    # load js from git/occ
     def loader_json(self, js):
         self.js = js
         self.name = js['name']
         self.depends = js['depends']
         self.description = js['description']
-        self.version = js['versions']
+        self.version = js['versions'] # FIXME:
         self.type = js['type']
         # self.repo_url = js['aboutURL']
 
@@ -90,7 +98,7 @@ class Component:
 
             # put_string("%s(%s), clone %s %s ..." % (self.name, self.version, self.repo_url, self.path))
             # put_string("%s(%s) ..." % (self.name, self.version))
-            prj.pull(self.version, None)
+            prj.pull(self.branch, None)
 
         elif self.version in self.historyVersion.keys():
             zip_url = self.historyVersion[self.version]
@@ -102,15 +110,18 @@ class Component:
                 zipf.extractall('.')
 
     def upload(self):
+        if not self.check_file_integrity():
+            exit(-1)
+
         repo_url = os.path.join(self.conf.repo, '%s.git' % self.name)
         try:
             prj = GitRepo('/tmp/' + self.name)
             prj.set_remote(repo_url)
-            prj.pull(self.version)
-            prj.import_path(self.path, self.version)
+            prj.pull(self.branch)
+            prj.import_path(self.path, self.branch)
             # repo.branch_to_tag(self.name, 'v7.2-dev', 'V7.2.2')
         except:
-            put_string("component `%s` upload fial." % self.name)
+            put_string("Component `%s` upload fail." % self.name)
 
         try:
             shutil.rmtree('/tmp/' + self.name)
@@ -150,6 +161,8 @@ class Component:
     def load_package(self):
         if self.type:
             return
+        if self.loaded:
+            return
 
         filename = os.path.join(self.path, 'package.yaml')
         pack = Package(filename)
@@ -157,16 +170,16 @@ class Component:
         if os.path.basename(self.path) != pack.name:
             logger.warning(
                 "component `%s`, but the directory is `%s`." % (pack.name, filename))
-
+        # FIXME:
         if self.repo:
-            self.version = self.repo.active_branch.name
+            self.branch = self.repo.active_branch.name
 
         self.name = pack.name
+        self.version = pack.version
         self.type = pack.type
         self.tag = pack.tag
         self.license = pack.license
         self.description = pack.description
-        self.yoc_version = pack.yoc_version
         self.source_files = pack.source_file
         self.build_config = copy.deepcopy(pack.build_config)
         self.defconfig = copy.deepcopy(pack.defconfig)
@@ -183,6 +196,7 @@ class Component:
                     self.depends.append(k)
             else:
                 self.depends.append(d)
+        self.loaded = True
 
     def variable_convert(self, varList):
         # include
@@ -193,9 +207,8 @@ class Component:
                 path = os.path.join(self.path, inc)
                 if not (os.path.isdir(path) and os.path.exists(path)):
                     logger.warning('%s is not exists or not directory.' % path)
-
-            if path not in incs:
-                incs.append(path)
+                if path not in incs:
+                    incs.append(path)
         self.build_config.include = incs
 
         # libpath
@@ -374,25 +387,33 @@ class ComponentGroup(list):
             task_pool.putRequest(req)
         task_pool.wait()
 
-    def get_depend(self, component):
+    def get_depend(self, component, exclude_names=[]):
+        arr_non = []
         def _check_depend(component):
             component.load_package()
 
             for name in component.depends:
-                if type(name) == dict:
-                    name = name['name']
-                c = self.components.get(name)
-                if c:
-                    if c not in depends:
-                        depends.append(c)
-                    if component not in c.depends_on:
-                        c.depends_on.append(component)
-                    _check_depend(c)
+                if name not in exclude_names:
+                    if type(name) == dict:
+                        name = name['name']
+
+                    if not self.get(name):
+                        if name not in arr_non:
+                            put_string("There is no depend component `%s` found!" % name)
+                            arr_non.append(name)
+
+                    c = self.components.get(name)
+                    if c:
+                        if c not in depends:
+                            depends.append(c)
+                        if component not in c.depends_on:
+                            c.depends_on.append(component)
+                        _check_depend(c)
 
         depends = ComponentGroup()
 
         _check_depend(component)
-        return depends
+        return depends, len(arr_non) > 0
 
 
 def string_strip(text, size):
