@@ -7,6 +7,7 @@ import sys
 import json
 import time
 import getpass
+import ssl
 
 try:
     raw_input = raw_input
@@ -45,17 +46,17 @@ class OCC:
 
         cmd = '/api/base/auth/login'
         body = {
-            "name": self.conf.username,
-            "password": self.conf.password
+            "name": str(self.conf.username),
+            "password": str(self.conf.password)
         }
         js, code = self.request(cmd, body)
         if code == 0:
-            if 'userToken' in js:
-                authorization = js['userToken']
-                login_time = time.time()
+            authorization = js['result']
+            login_time = time.time()
 
             return True
-
+        else:
+            return False
 
     def login(self):
         if not self._login():
@@ -143,7 +144,7 @@ class OCC:
             body = json.dumps(body)
             url = get_url(url, body)
 
-        connection = http.HTTPSConnection(self.conf.occ_host)
+        connection = http.HTTPSConnection(self.conf.occ_host, timeout=30, context=ssl._create_unverified_context())
 
         try:
             if not headers:
@@ -152,14 +153,11 @@ class OCC:
             response = connection.getresponse()
             if response.status == 200:
                 text = response.read()
-                if type(text) == bytes:
-                    text = bytes.decode(text)
-
                 js = json.loads(text)
 
                 if js['code'] != 0:
                     logger.error(js['msg'])
-                return js['result'], js['code']
+                return js, js['code']
         except Exception as e:
             logger.error(str(e))
 
