@@ -8,6 +8,7 @@ import json
 import shutil
 import glob
 import codecs
+import re
 
 from .tools import *
 from .log import logger
@@ -138,7 +139,7 @@ class HardwareInfo:
 #   cpu_id: cpu0
 #   board_name: pangu_cpu0
 #   cpu_name: CK805EF
-#   vendor_name: csky
+#   vendor_name: thead
 #   chip_name: 'chip_pangu'
 #   ld_script: configs/gcc_eflash.ld.S
 
@@ -245,13 +246,11 @@ class Package(object):
         self.description = ''
         self.type = ''
         self.tag = ''
-        self.yoc_version = ''
         self.version = ''
         self.keywords = {}
         self.author = {}
         self.license = ''
         self.homepage = ''
-        self.yoc_version = ''
         self.depends = {}
         self.build_config = build_config({})
         self.defconfig = {}
@@ -263,13 +262,39 @@ class Package(object):
         if filename:
             self.load(filename)
 
+    def check_name(self):
+        # name
+        if not self.name:
+            put_string('%s: `name` cannot be empty!' % self.filename)
+            return False
+        elif is_contain_chinese(self.name):
+            put_string("%s: `name` can't be chinese!" % self.filename)
+            return False
+        elif len(self.name) > 64:
+            put_string("%s: `name` is too long, max length is 64." % self.filename)
+            return False
+        elif not is_leagal_name(self.name):
+            put_string("%s: `name` does not conform to naming conventions." % self.filename)
+            return False
+
+        return True
+
     def load(self, filename):
         conf = yaml_load(filename)
         if not conf:
             return
 
+        had_err = 0
+        conf_str = ''
         for k, v in conf.items():
             if v:
+                if isinstance(v, list):
+                    while None in v:
+                        v.remove(None)
+                        had_err = 1
+                    if had_err:
+                        conf_str = k
+
                 if k == 'build_config':
                     v = build_config(v)
                 if k in ['board', 'chip', 'solution', 'hw_info']:
@@ -281,20 +306,31 @@ class Package(object):
                 else:
                     self.__dict__[k] = v
 
+        if had_err:
+            put_string("warning: '%s' config may be err in %s. You may be fix this by using command like `yoc format name of the component`!" % (conf_str, filename))
+
         if self.type in ['board', 'chip', 'solution']:
             if self.type not in conf and 'hw_info' not in conf:
-                logger.error('%s component must set `%s` field' %
-                             (filename, self.type))
+                put_string('%s component must set `type` field' % filename)
                 exit(-1)
 
-        if not self.name:
-            logger.error('%s `name` cannot be empty!' % filename)
+        if not self.check_name():
             exit(-1)
 
-        if self.type not in ['solution', 'common', 'board', 'chip']:
-            logger.error(
-                '%s `type` must be "solution" or "common" or "board" or "chip".' % filename)
+        # description
+        if not self.description:
+            put_string('%s: `description` cannot be empty!' % filename)
             exit(-1)
+        # version FIXME:
+        if not self.version:
+            logger.warn('%s: `version` cannot be empty!' % filename)
+            # exit(-1)
+
+        if self.type not in ['solution', 'common', 'board', 'chip']:
+            put_string(
+                '%s: `type` must be "solution" or "common" or "board" or "chip".' % filename)
+            exit(-1)
+
         text = self.hw_info.check(self.type)
 
         if text:
@@ -320,7 +356,7 @@ class Package(object):
         text = '''
 ## 第一部分： 基础信息
 {name}{version}{description}{type}
-{tag}{keywords}{homepage}{yoc_version}{author}{license}
+{tag}{keywords}{homepage}{author}{license}
 ## 第二部分：依赖信息
 #           指定该组件依赖的组件及版本，版本支持条件比较，支持：>=v1.0, >v1.0, ==v1.0, <=v1.0, <v1.0, v1.0
 #           未指定条件时，默认为 ==，如 v1.0 与 ==v1.0
@@ -362,18 +398,17 @@ class Package(object):
         return text.format(
             name=self.text_out('name', self.name,
                                '# <必选项> 包名称 （符合C语言变量命名规则），长度少于等于64字节'),
-            version=self.text_out('version', self.version),
+            version=self.text_out('version', self.version, '# <必选项> 组件版本号'),
             description=self.text_out(
                 'description', self.description, '# <必选项> 建议至少20字以上'),
             tag=self.text_out('tag', self.tag, "# <可选项> 组件分类，缺省值： ''"),
-            yoc_version=self.text_out('yoc_version', self.yoc_version),
             keywords=self.keywords_out(),
             author=self.author_out(),
             license=self.text_out(
                 'license', self.license, '# <可选项> 源代码的许可证，要确保所有代码、文件的许可证不冲突。如：MIT，Apache license v2.0，BSD'),
             homepage=self.text_out('homepage', self.homepage),
             type=self.text_out(
-                'type', self.type, '# <可选项> 组件类型，为：solution, chip, board, common，缺省值 common'),
+                'type', self.type, '# <必选项> 组件类型，为：solution, chip, board, common'),
             depends=self.depends_out(),
             source_file=self.fsource_file_out(),
             install=self.install_out('install', self.install),
@@ -384,7 +419,6 @@ class Package(object):
         )
 
     def save(self, filename):
-        print(filename)
         text = self.dumps()
         try:
             with codecs.open(filename or self.filename, 'w') as f:
