@@ -9,13 +9,15 @@ from __future__ import print_function
 # import github
 # import gitlab
 import json
+import os
 
-from .tools import http_request
+from .tools import *
 
 
 class RepoGitee:
     def __init__(self, token=None):
         self.tokenAccess = token
+        self.group = "yocop"
 
     def projects(self, count=10000000):
         page = 1
@@ -23,8 +25,8 @@ class RepoGitee:
         all_json = []
         while page <= total_page and len(all_json) < count:
             per_page = min(count, 100)
-            url = 'https://gitee.com/api/v5/orgs/yocopen/repos?access_token=%s&type=all&page=%d&per_page=%d' % (
-                self.tokenAccess, page, per_page)
+            url = 'https://gitee.com/api/v5/orgs/%s/repos?access_token=%s&type=all&page=%d&per_page=%d' % (
+                self.group, self.tokenAccess, page, per_page)
             headers = {'Content-Type': 'application/json;charset=UTF-8'}
 
             code, data, headers = http_request('GET', url, headers=headers)
@@ -37,12 +39,12 @@ class RepoGitee:
         return all_json
 
     def create_project(self, name, description=''):
-        url = 'https://gitee.com/api/v5/orgs/yocopen/repos'
+        url = 'https://gitee.com/api/v5/orgs/%s/repos' % self.group
         headers = {'Content-Type': 'application/json;charset=UTF-8'}
 
         data = {
             "access_token": self.tokenAccess,
-            "name": name, "has_issues": "true", "has_wiki": "true", "private": "true",
+            "name": name, "has_issues": "true", "has_wiki": "true", "private": "false",
             "description": description,
             # "license_template":"Apache-2.0",
         }
@@ -54,8 +56,8 @@ class RepoGitee:
             return self.update_project(name, description)
 
     def get_project(self, name):
-        url = 'https://gitee.com/api/v5/repos/yocopen/%s?access_token=%s' % (
-            name, self.tokenAccess)
+        url = 'https://gitee.com/api/v5/repos/%s/%s?access_token=%s' % (
+            self.group, name, self.tokenAccess)
         headers = {'Content-Type': 'application/json;charset=UTF-8'}
 
         data = {
@@ -68,8 +70,8 @@ class RepoGitee:
             return v['ssh_url']
 
     def remove_project(self, name):
-        url = 'https://gitee.com/api/v5/repos/yocopen/%s?access_token=%s' % (
-            name, self.tokenAccess)
+        url = 'https://gitee.com/api/v5/repos/%s/%s?access_token=%s' % (
+            self.group, name, self.tokenAccess)
 
         headers = {'Content-Type': 'application/json;charset=UTF-8'}
 
@@ -83,9 +85,9 @@ class RepoGitee:
     def branch_to_tag(self, name, branch, tag_name):
         # curl -X POST --header 'Content-Type: application/json;charset=UTF-8'
         # 'https://gitee.com/api/v5/repos/yocopen/newlib/releases'
-        # -d '{"access_token":"211f69d3691cd241f123df4d6d98ed80",
+        # -d '{"access_token":"c4d2f6d45952367bxxxxxx",
         # "tag_name":"v7.2.1","name":"v7.2.1","body":"v7.2.1","target_commitish":"v7.2-dev"}'
-        url = 'https://gitee.com/api/v5/repos/yocopen/%s/releases' % name
+        url = 'https://gitee.com/api/v5/repos/%s/%s/releases' % (self.group, name)
 
         headers = {'Content-Type': 'application/json;charset=UTF-8'}
 
@@ -105,17 +107,17 @@ class RepoGitee:
 
     def update_project(self, name, description=''):
         # curl -X PATCH --header 'Content-Type: application/json;charset=UTF-8'
-        # 'https://gitee.com/api/v5/repos/yocopen/yunvoice' -d '{"access_token":"661bc4c24596496dae61a2079288475c","name":"yunvoice",
+        # 'https://gitee.com/api/v5/repos/yocopen/yunvoice' -d '{"access_token":"c4d2f6d45952367bxxxxxx","name":"yunvoice",
         # "description":"{\"name\": \"yunvoice\", \"description\": \"yunvoice\", \"versions\": \"v7.2-dev\", \"license\": \"\", \"type\": \"common\", \"depends\": []}",
         # "has_issues":"true","has_wiki":"true"}
         # '
 
-        url = 'https://gitee.com/api/v5/repos/yocopen/' + name
+        url = 'https://gitee.com/api/v5/repos/%s/%s' % (self.group, name)
         headers = {'Content-Type': 'application/json;charset=UTF-8'}
 
         data = {
             "access_token": self.tokenAccess,
-            "name": name, "has_issues": "true", "has_wiki": "true", "private": "true",
+            "name": name, "has_issues": "true", "has_wiki": "true", "private": "false",
             "description": description,
             # "license_template":"Apache-2.0",
         }
@@ -127,6 +129,97 @@ class RepoGitee:
             v = json.loads(data)
             put_string(v)
 
+    def set_branch_protection(self, name, branch):
+        # curl -X PUT --header 'Content-Type: application/json;charset=UTF-8' 
+        # 'https://gitee.com/api/v5/repos/yocop/test_cmp/branches/test2/protection' 
+        # -d '{"access_token":"c4d2f6d45952367bxxxxxx"}'
+        url = 'https://gitee.com/api/v5/repos/%s/%s/branches/%s/protection' % (self.group, name, branch)
+
+        headers = {'Content-Type': 'application/json;charset=UTF-8'}
+
+        data = {
+            "access_token": self.tokenAccess,
+        }
+        code, data, _ = http_request('PUT', url, json.dumps(data), headers)
+
+        if code == 200:
+            v = json.loads(data)
+            put_string("保护分支设置成功.")
+        else:
+            v = json.loads(data)
+            put_string(v['message'])
+
+    def add_user_to_repo(self, repo, username):
+        # curl -X PUT --header 'Content-Type: application/json;charset=UTF-8' 
+        # 'https://gitee.com/api/v5/repos/yocop/test_cmp/collaborators/aaa' 
+        # -d '{"access_token":"c4d2f6d45952367bxxxxxx","permission":"push"}'
+        url = 'https://gitee.com/api/v5/repos/%s/%s/collaborators/%s' % (self.group, repo, username)
+
+        headers = {'Content-Type': 'application/json;charset=UTF-8'}
+
+        data = {
+            "access_token": self.tokenAccess,
+            "permission":"push",
+        }
+        code, data, _ = http_request('PUT', url, json.dumps(data), headers)
+
+        if code == 200:
+            v = json.loads(data)
+            put_string("添加用户到仓库成功.")
+        else:
+            v = json.loads(data)
+            put_string(v['message'])
+
+    def delete_user_to_repo(self, repo, username):
+        # curl -X DELETE --header 'Content-Type: application/json;charset=UTF-8' 
+        # 'https://gitee.com/api/v5/repos/yocop/test_cmp/collaborators/aaa?access_token=c4d2f6d45952367bxxxxxx'
+        url = 'https://gitee.com/api/v5/repos/%s/%s/collaborators/%s' % (self.group, repo, username)
+
+        headers = {'Content-Type': 'application/json;charset=UTF-8'}
+
+        data = {
+            "access_token": self.tokenAccess,
+        }
+        code, data, _ = http_request('DELETE', url, json.dumps(data), headers)
+
+        if code == 204:
+            put_string("移除用户成功.")
+        else:
+            v = json.loads(data)
+            put_string(v['message'])
+
+    def add_public_key(self):
+        id_ras_pub = home_path('.ssh/id_rsa.pub')
+        if not os.path.isfile(id_ras_pub):
+            cmd = "ssh-keygen -f ~/.ssh/id_rsa -N ' ' -t rsa"
+            os.system(cmd)
+
+        try:
+            with codecs.open(id_ras_pub, 'r') as f:
+                pub_key = f.read()
+                k = pub_key.split(' ')
+                if len(k) == 3:
+                    title = k[2]
+
+                url = 'https://gitee.com/api/v5/user/keys'
+                headers = {'Content-Type': 'application/json;charset=UTF-8'}
+
+                data = {
+                    "access_token": self.tokenAccess,
+                    "key": pub_key,
+                    "title": title
+                }
+
+                code, data, _ = http_request(
+                    'POST', url, json.dumps(data), headers)
+                v = json.loads(data)
+                put_string(v['message'])
+                if code == 200:
+                    return v['id']
+        except Exception as ex:
+            put_string(str(ex))
+            pass
+
 
 class RepoCodeup:
     def __init__(self, token=None):
@@ -135,7 +228,6 @@ class RepoCodeup:
     def projects(self):
         pass
 
-
     def create_project(self, name, description=''):
         headers = {
             'Ao-User-Locale': 'zh_CN',
