@@ -19,15 +19,19 @@ class Variables:
         pass
 
     def set(self, k, v, lower=False):
-        self.vars[k] = v
         if lower:
             self.vars[k.lower()] = v.lower()
+        else:
+            self.vars[k] = v
 
     def get(self, var):
         if var in self.vars:
             return self.vars[var]
 
     def convert(self, var):
+        if var == None or len(var) == 0:
+            return None
+
         v = var.split('?')
         if len(v) > 1:
             x = re.search('<(.+?)>', v[1], re.M | re.I)
@@ -43,7 +47,7 @@ class Variables:
             if value != None:
                 var = var.replace('<'+key+'>', self.vars[key])
             else:
-                put_string('not found variable:', var)
+                put_string('Not found variable:', var)
 
         return var
 
@@ -134,8 +138,19 @@ class Solution:
         def cpu_set_variable(cpu, arch):
             self.cpu_name = cpu
             self.variables.set('CPU', cpu.upper(), True)
-            if cpu.lower() == 'rv32emc':
-                self.variables.set('cpu_num', 'rv32')
+            if cpu.lower() == 'rv32emc' or cpu.lower().startswith('e'):
+                if cpu.lower() == 'rv32emc':
+                    self.variables.set('cpu_num', 'rv32')
+                elif cpu.lower() == 'e902':
+                    self.variables.set('cpu_num', 'rv32_16gpr')
+                elif cpu.lower() == 'e906':
+                    self.variables.set('cpu_num', 'rv32_32gpr')
+                elif cpu.lower() == 'e906f':
+                    self.variables.set('cpu_num', 'rv32f_32gpr')
+                elif cpu.lower() == 'e906fd':
+                    self.variables.set('cpu_num', 'rv32fd_32gpr')
+                else:
+                    logger.error("not support rv arch:%s yet" % arch)
                 self.variables.set('arch', 'RISCV', True)
             # elif cpu.lower() == 'ck803ef':
             #     self.variables.set('cpu_num', '803ef')
@@ -144,7 +159,7 @@ class Solution:
                 if arch == '' or arch.upper() == 'CSKY':
                     self.variables.set('cpu_num', cpu_id(cpu))
                     self.variables.set('ARCH', 'CSKY', True)
-                elif arch == 'arm':
+                elif arch.upper() == 'ARM':
                     self.variables.set('cpu_num', arm_cpu_id(cpu))
                     self.variables.set('ARCH', arch, True)
                 else:
@@ -175,6 +190,9 @@ class Solution:
             for k, v in solution_hw_info.cpu_list[solution_hw_info.cpu_id].items():
                 solution_hw_info.__dict__[k] = v
 
+        # board 的hw_info 次优先
+        if self.board_component and self.board_component.hw_info:
+            solution_hw_info.merge(self.board_component.hw_info, True)
         # soution 的hw_info 优先
         solution_hw_info.merge(self.solution_component.hw_info, True)
 
@@ -187,7 +205,7 @@ class Solution:
                              solution_hw_info.arch_name)
 
         if solution_hw_info.cpu_id:
-            self.variables.set(solution_hw_info.cpu_id.upper(), 1)
+            self.variables.set(solution_hw_info.cpu_id.upper(), True)
 
         if solution_hw_info.vendor_name:
             self.variables.set(
@@ -216,7 +234,7 @@ class Solution:
             self.solution_component.path, 'include'))
 
         for component in self.components:
-            if len(component.source_files) > 0 and component.type != 'solution' and component.name not in self.libs:
+            if len(component.source_files) > 0 and component.name not in self.libs:
                 self.libs.append(component.name)
                 self.depend_libs.append(os.path.join(
                     self.lib_path, 'lib' + component.name + '.a'))
@@ -238,22 +256,23 @@ class Solution:
                 if lib not in self.libs:
                     self.libs.append(lib)
 
+        self.toolchain_prefix = solution_hw_info.toolchain_prefix
+        self.ld_script = solution_hw_info.ld_script
+        self.ld_script = self.variables.convert(self.ld_script)
+
         if self.solution_component.hw_info.ld_script:
-            self.ld_script = self.solution_component.hw_info.ld_script
             self.ld_script_component = self.solution_component
         elif self.board_component and self.board_component.hw_info.ld_script:
-            self.ld_script = self.board_component.hw_info.ld_script
             self.ld_script_component = self.board_component
         elif self.chip_component and self.chip_component.hw_info.ld_script:
-            self.ld_script = self.chip_component.hw_info.ld_script
+            self.ld_script_component = self.chip_component
+        elif self.chip_component and self.ld_script:
+            # multi cpu
             self.ld_script_component = self.chip_component
         else:
             logger.error("not found LD script file, please set ld_script")
             exit(-1)
 
-        self.toolchain_prefix = solution_hw_info.toolchain_prefix
-        self.ld_script = self.variables.convert(self.ld_script)
-
     def install(self):
         for component in self.components:
             component.install(self.yoc_path)
