@@ -19,7 +19,7 @@ import os
 all_commands = {}
 
 
-exclude_cmd = ['branch', 'checkout', 'uninstall', 'sync']
+exclude_cmd = ['branch', 'checkout', 'uninstall', 'cdk']
 
 my_dir = os.path.dirname(__file__)
 for py in os.listdir(my_dir):
