@@ -5,6 +5,7 @@
 
 from __future__ import print_function
 
+import os
 from yoctools import *
 
 
@@ -24,6 +25,6 @@ Format component package.yaml file
         count = len(args)
         for component in yoc.components:
             if count == 0 or component.name in args:
-                put_string("formating package: %s" % component.name)
+                put_string("Formating package: %s." % component.name)
                 component.load_package()
-                component.pack.save()
+                component.pack.save(os.path.join(component.path, 'package.yaml'))
