@@ -5,9 +5,9 @@
 
 from __future__ import print_function
 
+import os
 from yoctools import *
 
-
 class Init(Command):
     common = True
     helpSummary = "Initialize yoc workspace in the current directory"
@@ -18,5 +18,11 @@ class Init(Command):
 Initialize yoc workspace in the current directory.
 """
     def Execute(self, opt, args):
-        conf = Configure()
-        conf.save()
+        try:
+            urlretrieve('https://yoctools.oss-cn-beijing.aliyuncs.com/yoc', '.yoc')
+        except:
+            pass
+        if not os.path.isfile('.yoc'):
+            conf = Configure()
+            conf.yoc_version = 'v7.3.0'
+            conf.save()
