@@ -23,10 +23,6 @@ List all projects; pass '.' to list the project for the cwd.
                      dest='show_remote', action='store_true',
                      help='show OCC all compoent')
 
-        p.add_option('-u', '--upgrade',
-                     dest='upgrade', action='store_true',
-                     help='upgrade component')
-
         p.add_option('-b', '--board',
                      dest='board', action='store_true',
                      help='list all board component')
@@ -45,33 +41,46 @@ List all projects; pass '.' to list the project for the cwd.
 
         p.add_option('-d', '--depend',
                      dest='depend', action='store_true',
-                     help='List component dependencies')
+                     help='list component dependencies')
 
     def Execute(self, opt, args):
         yoc = YoC()
-        if opt.upgrade:
-            yoc.gitee_update()
 
         count = len(args)
 
         if opt.show_remote:
-            if not yoc.occ_components:
-                yoc.gitee_update()
+            yoc.gitee_update()
             group = yoc.occ_components
         else:
             group = yoc.components
             for c in group:
                 if count == 0 or c.name in args:
                     c.load_package()
+        
+        if len(group) == 0:
+            put_string("There is no component found!")
+            exit(-1)
+
+        nonexistent_cnt = 0
+        name_list = yoc.get_name_list(group)
+        for name in args:
+            if name not in name_list:
+                put_string("Can't found component `%s`!" % name)
+                nonexistent_cnt+=1
 
         show = opt.board or opt.chip or opt.common or opt.solution
+        show_cnt = 0
         for c in group:
             if count == 0 or c.name in args:
                 if show:
                     if (opt.board and c.type == 'board') or (opt.chip and c.type == 'chip') or (opt.common and c.type == 'common') or (opt.solution and c.type == 'solution'):
                         self.show_depend(yoc, c, opt.depend)
+                        show_cnt+=1
                 else:
                     self.show_depend(yoc, c, opt.depend)
+                    show_cnt +=1
+        if show_cnt == 0 and nonexistent_cnt == 0:
+            put_string('No matched component found!')
 
     def show_depend(self, yoc, component, show_depend=False):
         component.load_package()
