@@ -26,16 +26,21 @@ Search for components whose name or summary contains <query>
     def Execute(self, opt, args):
         if len(args) != 1:
             self.Usage()
+        kword = args[0]
+        if is_contain_chinese(kword.encode('utf8').decode('utf8')):
+            put_string("Not support search chinese string!")
+            exit(-1)
 
         yoc = YoC()
         if opt.upgrade or yoc.occ_components == None:
             yoc.gitee_update()
 
         for component in yoc.occ_components:
-            search_text = args[0].lower()
+            keys = [kword, kword.lower(), kword.upper()]
+            search_text = kword.lower()
             if component.name.lower().find(search_text) >= 0:
-                component.show(key=[args[0]])
+                component.show(key=keys)
             else:
                 component.load_package()
                 if component.description.lower().find(search_text) >= 0:
-                    component.show(key=[args[0]])
+                    component.show(key=keys)
