@@ -15,8 +15,8 @@ import codecs
 from .tools import *
 
 
-toolchain_url_64 = "https://cop-image-prod.oss-cn-hangzhou.aliyuncs.com/resource/420257228264570880/1574927493455/csky-elfabiv2-tools-x86_64-minilibc-20191122.tar.gz"
-toolchain_url_32 = "https://cop-image-prod.oss-cn-hangzhou.aliyuncs.com/resource/420257228264570880/1574927450819/csky-elfabiv2-tools-i386-minilibc-20191122.tar.gz"
+toolchain_url_64 = "http://yoctools.oss-cn-beijing.aliyuncs.com/csky-elfabiv2-tools-x86_64-minilibc-20200407.tar.gz"
+toolchain_url_32 = "http://yoctools.oss-cn-beijing.aliyuncs.com/csky-elfabiv2-tools-i386-minilibc-20200407.tar.gz"
 
 rsicv_url_64 = 'https://cop-image-prod.oss-cn-hangzhou.aliyuncs.com/resource/420262990181302272/1577083328051/riscv64-elf-x86_64-20191111.tar.gz'
 rsicv_url_32 = 'https://cop-image-prod.oss-cn-hangzhou.aliyuncs.com/resource/420262990181302272/1577082864564/riscv64-elf-i386-20191111.tar.gz'
@@ -50,6 +50,7 @@ class ToolchainYoC:
         tar_path = '/tmp/' + os.path.basename(toolchain_url)
         wget(toolchain_url, tar_path)
         put_string("")
+        put_string("Start install, wait half a minute please.")
         with tarfile.open(tar_path, 'r:gz') as tar:
             tar.extractall(toolchain_path)
 
@@ -58,6 +59,7 @@ class ToolchainYoC:
             self.link_bin(toolchain_path)
         else:
             self.update_env(arch)
+        put_string("Congratulations!")
 
     def link_bin(self, toolchain_path):
         toolchain_bin = os.path.join(toolchain_path, 'bin')
@@ -73,7 +75,7 @@ class ToolchainYoC:
                     except FileExistsError:
                         pass
                     except PermissionError:
-                        put_string("please use: sudo", ' '.join(sys.argv))
+                        put_string("Please use: sudo", ' '.join(sys.argv))
                         exit(-1)
                     except Exception as e:
                         pass
@@ -111,11 +113,14 @@ class ToolchainYoC:
         with codecs.open(rc, 'w', 'UTF-8') as f:
             contents = f.writelines(contents)
 
-    def check_toolchain(self, arch='csky-abiv2-elf'):
+    def check_toolchain(self, arch='csky-abiv2-elf', verbose=0):
         bin_file = self.check_program(arch)
         if bin_file == '':
             self.download(arch)
             bin_file = self.check_program(arch)
+        else:
+            if verbose == 1:
+                put_string('warn: the toolchains was installed already, path = %s.' % bin_file)
         return bin_file
 
     def which(self, cmd):
